@@ -49,10 +49,6 @@
 
 package com.openexchange.chronos.provider.google.access;
 
-import static com.openexchange.chronos.provider.CalendarFolderProperty.COLOR;
-import static com.openexchange.chronos.provider.CalendarFolderProperty.DESCRIPTION;
-import static com.openexchange.chronos.provider.CalendarFolderProperty.LAST_UPDATE;
-import static com.openexchange.chronos.provider.CalendarFolderProperty.SCHEDULE_TRANSP;
 import static com.openexchange.chronos.provider.CalendarFolderProperty.USED_FOR_SYNC;
 import java.io.IOException;
 import java.util.ArrayList;
@@ -67,10 +63,10 @@ import com.google.api.services.calendar.Calendar;
 import com.google.api.services.calendar.model.CalendarList;
 import com.google.api.services.calendar.model.CalendarListEntry;
 import com.google.api.services.calendar.model.Events;
+import com.openexchange.annotation.Nullable;
 import com.openexchange.chronos.Event;
 import com.openexchange.chronos.ExtendedProperties;
 import com.openexchange.chronos.ExtendedProperty;
-import com.openexchange.chronos.TimeTransparency;
 import com.openexchange.chronos.common.DataHandlers;
 import com.openexchange.chronos.exception.CalendarExceptionCodes;
 import com.openexchange.chronos.provider.CalendarAccount;
@@ -105,8 +101,6 @@ import com.openexchange.session.Session;
  */
 public class GoogleCalendarAccess extends BasicCachingCalendarAccess {
 
-    private static final String DEFAULT_CALENDAR_NAME = "Google Calendar";
-
     private static final Logger LOG = LoggerFactory.getLogger(GoogleCalendarAccess.class);
 
     private final GoogleOAuthAccess oauthAccess;
@@ -123,7 +117,7 @@ public class GoogleCalendarAccess extends BasicCachingCalendarAccess {
      * @throws OXException
      */
     public GoogleCalendarAccess(Session session, CalendarAccount account, CalendarParameters parameters, boolean checkConfig) throws OXException {
-        super(session, account, parameters);
+        super(session, account, parameters, null);
         refreshInterval = GoogleCalendarConfig.getResfrehInterval(session);
         requestTimeout = GoogleCalendarConfig.getRetryOnErrorInterval(session);
         try {
@@ -270,10 +264,11 @@ public class GoogleCalendarAccess extends BasicCachingCalendarAccess {
         try {
             Calendar googleCal = (Calendar) oauthAccess.getClient().getClient();
             com.google.api.services.calendar.Calendar.Events.List list = googleCal.events().list(folderId);
+            list.setAlwaysIncludeEmail(Boolean.TRUE);
 
             if (token != null) {
                 if (isSyncToken) {
-                    list.setShowDeleted(true);
+                    list.setShowDeleted(Boolean.TRUE);
                     list.setSyncToken(token);
                 } else {
                     list.setPageToken(token);
@@ -310,17 +305,19 @@ public class GoogleCalendarAccess extends BasicCachingCalendarAccess {
      *
      * @param conversionService A reference to the conversion service
      * @param jsonObject The JSON object to parse the properties from
-     * @return The parsed extended properties
+     * @return The parsed extended properties or <code>null</code> if there aren't any.
      */
-    protected static ExtendedProperties parseExtendedProperties(ConversionService conversionService, JSONObject jsonObject) throws OXException {
-        if (null != jsonObject) {
-            DataHandler dataHandler = conversionService.getDataHandler(DataHandlers.JSON2XPROPERTIES);
-            if (null != dataHandler) {
-                ConversionResult result = dataHandler.processData(new SimpleData<JSONObject>(jsonObject), new DataArguments(), null);
-                if (null != result && null != result.getData() && ExtendedProperties.class.isInstance(result.getData())) {
-                    return (ExtendedProperties) result.getData();
-                }
-            }
+    protected @Nullable static ExtendedProperties parseExtendedProperties(ConversionService conversionService, JSONObject jsonObject) throws OXException {
+        if (null == jsonObject) {
+            return null;
+        }
+        DataHandler dataHandler = conversionService.getDataHandler(DataHandlers.JSON2XPROPERTIES);
+        if (null == dataHandler) {
+            return null;
+        }
+        ConversionResult result = dataHandler.processData(new SimpleData<JSONObject>(jsonObject), new DataArguments(), null);
+        if (null != result && null != result.getData() && ExtendedProperties.class.isInstance(result.getData())) {
+            return (ExtendedProperties) result.getData();
         }
         return null;
     }
@@ -338,25 +335,13 @@ public class GoogleCalendarAccess extends BasicCachingCalendarAccess {
 
     @Override
     public CalendarSettings getSettings() {
-        CalendarSettings settings = new CalendarSettings();
-        settings.setLastModified(account.getLastModified());
-        settings.setConfig(account.getUserConfiguration());
-        JSONObject internalConfig = account.getInternalConfiguration();
-        settings.setName(internalConfig.optString("name", DEFAULT_CALENDAR_NAME));
-        ExtendedProperties extendedProperties = new ExtendedProperties();
-        extendedProperties.add(SCHEDULE_TRANSP(TimeTransparency.TRANSPARENT, true));
-        extendedProperties.add(DESCRIPTION(internalConfig.optString(GoogleCalendarConfigField.DESCRIPTION, null), false));
-        extendedProperties.add(USED_FOR_SYNC(Boolean.FALSE, true));
-        extendedProperties.add(COLOR(internalConfig.optString(GoogleCalendarConfigField.COLOR, null), false));
-        extendedProperties.add(LAST_UPDATE(optLastUpdate()));
-        settings.setExtendedProperties(extendedProperties);
-        settings.setSubscribed(true);
-        settings.setError(optAccountError());
+        CalendarSettings settings = super.getSettings();
+        settings.getExtendedProperties().replace(USED_FOR_SYNC(Boolean.FALSE, true)); // never synchronizable
         return settings;
     }
 
     @Override
-    public List<OXException> getWarnings() {
+    public @Nullable List<OXException> getWarnings() {
         // TODO handle warnings
         return null;
     }
