@@ -49,22 +49,30 @@
 
 package com.openexchange.chronos.provider.google.access;
 
+import static com.openexchange.chronos.common.CalendarUtils.getRecurrenceIds;
+import static com.openexchange.chronos.common.CalendarUtils.sortSeriesMasterFirst;
 import java.util.ArrayList;
 import java.util.Calendar;
 import java.util.Collections;
+import java.util.LinkedHashMap;
 import java.util.List;
+import java.util.Map;
 import java.util.SortedSet;
 import java.util.TreeSet;
+import java.util.stream.Collectors;
 import org.json.JSONException;
 import org.json.JSONObject;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
+import com.google.api.client.googleapis.json.GoogleJsonResponseException;
 import com.openexchange.chronos.Event;
 import com.openexchange.chronos.EventField;
 import com.openexchange.chronos.EventStatus;
 import com.openexchange.chronos.RecurrenceId;
-import com.openexchange.chronos.common.mapping.EventMapper;
+import com.openexchange.chronos.common.CalendarUtils;
+import com.openexchange.chronos.common.Check;
 import com.openexchange.chronos.common.mapping.DefaultEventUpdate;
+import com.openexchange.chronos.common.mapping.EventMapper;
 import com.openexchange.chronos.exception.CalendarExceptionCodes;
 import com.openexchange.chronos.provider.caching.DiffAwareExternalCalendarResult;
 import com.openexchange.chronos.provider.caching.ExternalCalendarResult;
@@ -86,7 +94,7 @@ public class GoogleCalendarResult extends ExternalCalendarResult implements Diff
     private static final Logger LOG = LoggerFactory.getLogger(GoogleCalendarResult.class);
 
     private final GoogleCalendarAccess access;
-    private final GoogleEventsPage currentResult;
+    private GoogleEventsPage currentResult;
     private String folderId;
 
     /**
@@ -117,8 +125,15 @@ public class GoogleCalendarResult extends ExternalCalendarResult implements Diff
         } catch (JSONException e) {
             throw CalendarExceptionCodes.UNEXPECTED_ERROR.create(e, e.getMessage());
         }
-
-        currentResult = access.getEventsInFolder(folderId, token, true);
+        try {
+            currentResult = access.getEventsInFolder(folderId, token, true);
+        } catch (OXException e) {
+            if(isSynTokenInvalidException(e)) {
+                currentResult = access.getEventsInFolder(folderId, null, false);
+            } else {
+                throw e;
+            }
+        }
     }
 
     private String getFolder() throws OXException {
@@ -136,15 +151,35 @@ public class GoogleCalendarResult extends ExternalCalendarResult implements Diff
         }
         return folderId;
     }
+    
+    private static final EventField[] FIELDS_TO_IGNORE = new EventField[] { EventField.CREATED_BY, EventField.FOLDER_ID, EventField.ID, EventField.CALENDAR_USER, EventField.CREATED, EventField.MODIFIED_BY, EventField.EXTENDED_PROPERTIES, EventField.TIMESTAMP };
+    private static final EventField[] EQUALS_IDENTIFIER = new EventField[] { EventField.UID, EventField.RECURRENCE_ID };
 
     @Override
     public EventUpdates calculateDiff(List<Event> existingEvents) throws OXException {
 
         List<Event> updates = currentResult.getEvents();
         GoogleEventsPage page = currentResult;
-        while(page.getToken() != null) {
-            page = access.getEventsInFolder(getFolder(), page.getToken(), false);
-            updates.addAll(page.getEvents());
+        try {
+            while (page.getToken() != null) {
+                page = access.getEventsInFolder(getFolder(), page.getToken(), false);
+                updates.addAll(page.getEvents());
+            }
+        } catch (OXException e) {
+            if (isSynTokenInvalidException(e)) {
+                // Try a full synch in case of token errors
+                access.getAccount().getInternalConfiguration().remove(GoogleCalendarConfigField.SYNC_TOKEN);
+                Map<String, List<Event>> externalEvents = prepareExternalEvents(access.getEventsInFolder(getFolder(), null, false).getEvents());
+                List<Event> updatedEvents = externalEvents.values().stream().flatMap(List::stream).collect(Collectors.toList());
+                if (externalEvents.containsKey(null)) {
+                    /*
+                     * event source contains events without UID, use a replacing event update as fallback
+                     */
+                    return createUpdate(updatedEvents, Collections.emptyList(), existingEvents);
+                }
+                return CalendarUtils.getEventUpdates(existingEvents, updatedEvents, true, FIELDS_TO_IGNORE, EQUALS_IDENTIFIER);
+            }
+            throw e;
         }
 
         final List<Event> removed = new ArrayList<>();
@@ -195,7 +230,34 @@ public class GoogleCalendarResult extends ExternalCalendarResult implements Diff
 
         // Handle delete exceptions
         handleDeleteExceptions(deleteExceptions, existingEvents, added, updated, removed);
-
+        return createUpdate(added, updated, removed);
+    }
+    
+    private static final int SYNC_TOKEN_INVALID_CODE = 410;
+    
+    /**
+     * Checks whether the exception contains a google sync token is invalid exception
+     * 
+     * @param e The exception to check
+     * @return <code>true</code> if the exceptions contains a google sync token invalid exceptions 
+     */
+    private boolean isSynTokenInvalidException(OXException e) {
+        if (CalendarExceptionCodes.IO_ERROR.equals(e) && e.getCause() != null && e.getCause() instanceof GoogleJsonResponseException) {
+            GoogleJsonResponseException googleException = (GoogleJsonResponseException) e.getCause();
+            return googleException.getDetails().getCode() == SYNC_TOKEN_INVALID_CODE;
+        }
+        return false;
+    }
+    
+    /**
+     * Creates an {@link EventUpdates} object from the given parameters
+     * 
+     * @param added The added events
+     * @param updated The updated events
+     * @param removed The removed events
+     * @return A new {@link EventUpdates} instance
+     */
+    private EventUpdates createUpdate(List<Event> added, List<EventUpdate> updated, List<Event> removed) {
         return new EventUpdates() {
 
             @Override
@@ -219,6 +281,53 @@ public class GoogleCalendarResult extends ExternalCalendarResult implements Diff
             }
         };
     }
+    
+    /**
+     * Prepares the list of events from the external calendar source for further processing. This includes:
+     * <ul>
+     * <li>remove events that cannot be stored due to missing mandatory fields</li>
+     * <li>map events by their UID property (events without UID are mapped to <code>null</code>)</li>
+     * <li>event lists are sorted so that the series master event will be the first element</li>
+     * <li>the change exception field of series master events will be set based on the actual overridden instances</li>
+     * </ul>
+     *
+     * @param events The events to prepare
+     * @return The prepared events, mapped by their unique identifier (events without UID are mapped to <code>null</code>)
+     */
+    private static Map<String, List<Event>> prepareExternalEvents(List<Event> events) {
+        if (null == events) {
+            return Collections.emptyMap();
+        }
+        Map<String, List<Event>> eventsByUID = new LinkedHashMap<String, List<Event>>();
+        for (Event event : events) {
+            /*
+             * ignore events lacking mandatory fields
+             */
+            try {
+                Check.mandatoryFields(event, EventField.START_DATE);
+            } catch (OXException e) {
+                LOG.debug("Removed event with uid {} from list to add because of the following corrupt data: {}", event.getUid(), e.getMessage());
+                continue;
+            }
+            /*
+             * map events by UID
+             */
+            com.openexchange.tools.arrays.Collections.put(eventsByUID, event.getUid(), event);
+        }
+        for (List<Event> eventGroup : eventsByUID.values()) {
+            if (1 >= eventGroup.size()) {
+                continue;
+            }
+            /*
+             * sort series master first, then assign change exception dates
+             */
+            eventGroup = sortSeriesMasterFirst(eventGroup);
+            if (null != eventGroup.get(0).getRecurrenceRule()) {
+                eventGroup.get(0).setChangeExceptionDates(getRecurrenceIds(eventGroup.subList(1, eventGroup.size())));
+            }
+        }
+        return eventsByUID;
+    }
 
     /**
      * Checks if one of the given events is the master for the given uid.
